pub enum Projection {
Perspective(PerspectiveCamera),
Orthographic(OrthographicCamera),
}Expand description
Projection mode for a camera.
Variants
Perspective(PerspectiveCamera)
Perspective projection with foreshortening (3D games, realistic rendering).
Orthographic(OrthographicCamera)
Orthographic projection without foreshortening (2D games, CAD, isometric views).
Implementations
Sourceimpl Projection
impl Projection
Sourcepub fn matrix(&self) -> Matrix<f32, Const<4>, Const<4>, ArrayStorage<f32, 4, 4>>
pub fn matrix(&self) -> Matrix<f32, Const<4>, Const<4>, ArrayStorage<f32, 4, 4>>
Returns the projection matrix using default or stored aspect ratio.
Sourcepub fn matrix_with_aspect(
&self,
aspect_ratio: f32,
) -> Matrix<f32, Const<4>, Const<4>, ArrayStorage<f32, 4, 4>>
pub fn matrix_with_aspect( &self, aspect_ratio: f32, ) -> Matrix<f32, Const<4>, Const<4>, ArrayStorage<f32, 4, 4>>
Returns the projection matrix with the specified aspect ratio.
For perspective cameras, this overrides the stored aspect ratio. For orthographic cameras, aspect ratio is ignored.