pub enum Body {
None,
Static,
Dynamic {
mass: f32,
},
}Expand description
Physics participation for spawn_object. Requires the physics
feature, which is on by default.
Dynamic cubes, spheres, cylinders, and cones get exact colliders. A dynamic torus gets a convex hull of its mesh, which fills the hole. Static toruses and planes collide against the exact triangle mesh.
Variants