#[repr(u16)]pub enum GamepadAxis {
LeftStickX = 1,
LeftStickY = 2,
LeftZ = 3,
RightStickX = 4,
RightStickY = 5,
RightZ = 6,
DPadX = 7,
DPadY = 8,
Unknown = 0,
}Expand description
A gamepad analog axis: the two sticks (LeftStickX/Y, RightStickX/Y)
and the trigger axes (LeftZ/RightZ).
Gamepad’s elements which state can be represented by value from -1.0 to 1.0.
Variants
LeftStickX = 1
LeftStickY = 2
LeftZ = 3
RightStickX = 4
RightStickY = 5
RightZ = 6
DPadX = 7
DPadY = 8
Unknown = 0
Implementations
Sourceimpl Axis
impl Axis
Sourcepub fn is_stick(self) -> bool
pub fn is_stick(self) -> bool
Returns true if axis is LeftStickX, LeftStickY, RightStickX or RightStickY.
Sourcepub fn second_axis(self) -> Option<Axis>
pub fn second_axis(self) -> Option<Axis>
Returns the other axis from same element of gamepad, if any.
| input | output |
|---|---|
LeftStickX | Some(LeftStickY) |
LeftStickY | Some(LeftStickX) |
RightStickX | Some(RightStickY) |
RightStickY | Some(RightStickX) |
DpadX | Some(DpadY) |
DpadY | Some(DpadX) |
| … | None |