apply_patch

Function apply_patch 

pub fn apply_patch(world: &mut World, entity: Entity, patch: ComponentPatch)
Writes a ComponentPatch onto the entity, adding the component first for the variants whose presence is the value (visibility, casts-shadow, ignore-parent-scale, script).