spawn_model

Function spawn_model 

pub fn spawn_model(
    world: &mut World,
    glb_bytes: &[u8],
    position: Vec3,
) -> Entity
Spawns a glb model with its textures, materials, skins, and animations. Panics with the import error when the bytes are not a valid glb.