tree_node

Function tree_node 

pub fn tree_node(
    world: &mut World,
    tree_view: Entity,
    parent_container: Entity,
    label: &str,
    depth: usize,
    user_data: u64,
) -> Entity
Adds a node labeled label at depth under parent_container (a tree’s tree_content for a root node, or another node’s tree_node_children for a nested one). user_data is an id you choose to recognize the node.