attach

Function attach 

pub fn attach(
    envelope: &Object,
    transfer: &Array,
    attachments: &[(String, Vec<u8>)],
) -> bool
Adds named binary payloads to envelope and their buffers to transfer. Returns false when the attachment bag could not be written.