pub fn attachments_from(data: &JsValue) -> AttachmentsExpand description
Decodes the named binary attachments riding data, empty when none did.
pub fn attachments_from(data: &JsValue) -> AttachmentsDecodes the named binary attachments riding data, empty when none did.