pub enum Side {
Top,
Bottom,
Left,
Right,
}Expand description
The preferred side of the anchor on which to place a floating element. Placement may flip to the opposite side when there is not enough room.
Variants