CodeTabs

Function CodeTabs 

pub fn CodeTabs(props: CodeTabsProps) -> impl IntoView
A tabbed multi-document editor: renders a tab bar for documents, tracks the active document id, hosts a filling CodeEditor for the selection, and fires the optional on_close callback with a document id when its close button is clicked.

Required Props

Optional Props