Disclosure

Function Disclosure 

pub fn Disclosure(props: DisclosureProps) -> impl IntoView
A collapsible section with a clickable title header that shows or hides its children. Open state is controlled by the optional open signal, otherwise it starts from default_open.

Required Props

Optional Props