pub fn DockMain(props: DockMainProps) -> impl IntoViewExpand description
The flexible central region of a DockLayout that fills the space left by the panels.
Required Props
- children:
Children
Optional Props
- class:
impl Into<String>
pub fn DockMain(props: DockMainProps) -> impl IntoViewThe flexible central region of a DockLayout that fills the space left by the panels.
Childrenimpl Into<String>