DropZone

Function DropZone 

pub fn DropZone(props: DropZoneProps) -> impl IntoView
Wraps children as a drop target registered under id. Highlights while a drag hovers it and runs on_drop with the dropped DragPayload when a drag is released over it.

Required Props

Optional Props