pub fn InspectorRow(props: InspectorRowProps) -> impl IntoViewExpand description
A labeled inspector row pairing a label with a control rendered from
children.
Required Props
- label:
impl Into<String> - children:
Children
pub fn InspectorRow(props: InspectorRowProps) -> impl IntoViewA labeled inspector row pairing a label with a control rendered from
children.
impl Into<String>Children