pub fn Loader(props: LoaderProps) -> impl IntoViewExpand description
A full-surface overlay with a spinner and message, shown until ready becomes true.
Required Props
- ready:
RwSignal<bool>
Optional Props
- message:
impl Into<String>
pub fn Loader(props: LoaderProps) -> impl IntoViewA full-surface overlay with a spinner and message, shown until ready becomes true.
RwSignal<bool>impl Into<String>