MenuBar

Function MenuBar 

pub fn MenuBar(props: MenuBarProps) -> impl IntoView
An application menu bar that coordinates its MenuBarMenu children so only one is open at a time and hover switches between them once one is open.

Required Props