pub fn Submenu(props: SubmenuProps) -> impl IntoViewExpand description
A nested menu row that reveals its children in a flyout on hover or click.
Required Props
- label:
impl Into<String> - children:
ChildrenFn
pub fn Submenu(props: SubmenuProps) -> impl IntoViewA nested menu row that reveals its children in a flyout on hover or click.
impl Into<String>ChildrenFn