TabBar

Function TabBar 

pub fn TabBar(props: TabBarProps) -> impl IntoView
A horizontal row of tabs from (id, label) pairs, binding the selected id to active and cycling selection with the left and right arrow keys.

Required Props