pub fn Tooltip(props: TooltipProps) -> impl IntoViewExpand description
Wraps children in a focusable span that reveals text in a bubble on
hover or focus.
Required Props
- text:
impl Into<String> - children:
Children
pub fn Tooltip(props: TooltipProps) -> impl IntoViewWraps children in a focusable span that reveals text in a bubble on
hover or focus.
impl Into<String>Children