pub fn ViewportOverlay(props: ViewportOverlayProps) -> impl IntoViewExpand description
A positioning layer stacked over the render surface to hold HUD elements.
Required Props
- children:
Children
Optional Props
- class:
impl Into<String>
pub fn ViewportOverlay(props: ViewportOverlayProps) -> impl IntoViewA positioning layer stacked over the render surface to hold HUD elements.
Childrenimpl Into<String>