pub fn WebGpuGate(props: WebGpuGateProps) -> impl IntoViewExpand description
Renders children when WebGPU is available, or an explanatory fallback card when it is not.
Required Props
- children:
ChildrenFn
pub fn WebGpuGate(props: WebGpuGateProps) -> impl IntoViewRenders children when WebGPU is available, or an explanatory fallback card when it is not.
ChildrenFn