pub fn use_theme() -> RwSignal<String>Expand description
Get the active theme-id signal from context (provided by ThemeProvider),
or a standalone signal seeded from storage when no provider is present.
pub fn use_theme() -> RwSignal<String>Get the active theme-id signal from context (provided by ThemeProvider),
or a standalone signal seeded from storage when no provider is present.