pub enum FromFormDataError {
MissingForm(Event),
FormData(JsValue),
Deserialization(Error),
}Expand description
Errors that can arise when coverting from an HTML event or form into a Rust data type.
Variants
MissingForm(Event)
Could not find a <form> connected to the event.
FormData(JsValue)
Could not create FormData from the form.
Deserialization(Error)
Failed to deserialize this Rust type from the form data.