ServerFnError

Enum ServerFnError 

pub enum ServerFnError<E = NoCustomError> {
    WrappedServerError(E),
    Registration(String),
    Request(String),
    Response(String),
    ServerError(String),
    Deserialization(String),
    Serialization(String),
    Args(String),
    MissingArg(String),
}
Type for errors that can occur when using server functions.

Unlike ServerFnErrorErr, this does not implement Error. This means that other error types can easily be converted into it using the ? operator.

Variants



WrappedServerError(E)

A user-defined custom error type, which defaults to NoCustomError.



Registration(String)

Error while trying to register the server function (only occurs in case of poisoned RwLock).



Request(String)

Occurs on the client if there is a network error while trying to run function on server.



Response(String)

Occurs on the server if there is an error creating an HTTP response.



ServerError(String)

Occurs when there is an error while actually running the function on the server.



Deserialization(String)

Occurs on the client if there is an error deserializing the server’s response.



Serialization(String)

Occurs on the client if there is an error serializing the server function arguments.



Args(String)

Occurs on the server if there is an error deserializing one of the arguments that’s been sent.



MissingArg(String)

Occurs on the server if there’s a missing argument.

Implementations

Source

impl ServerFnError

pub fn new(msg: impl ToString) -> ServerFnError

Constructs a new ServerFnError::ServerError from some other type.