pub struct WriteGuard<S, G>where
S: Notify,{ /* private fields */ }Expand description
A guard that provides mutable access to a signal’s value, triggering some reactive change when it is dropped.
Implementations
Sourceimpl<S, G> WriteGuard<S, G>where
S: Notify,
impl<S, G> WriteGuard<S, G>where
S: Notify,
Sourcepub fn new(triggerable: S, guard: G) -> WriteGuard<S, G>
pub fn new(triggerable: S, guard: G) -> WriteGuard<S, G>
Creates a new guard from the inner mutable guard type, and the signal that should be triggered on drop.