ByteStream

Struct ByteStream 

pub struct ByteStream<CustErr = NoCustomError>(/* private fields */);
A stream of bytes.

A server function can return this type if its output encoding is Streaming.

Browser Support for Streaming Input

Browser fetch requests do not currently support full request duplexing, which means that that they do begin handling responses until the full request has been sent. This means that if you use a streaming input encoding, the input stream needs to end before the output will begin.

Streaming requests are only allowed over HTTP2 or HTTP3.

Implementations

Source

impl<CustErr> ByteStream<CustErr>

pub fn into_inner( self, ) -> impl Stream<Item = Result<Bytes, ServerFnError<CustErr>>> + Send

Consumes the wrapper, returning a stream of bytes.

Source

impl ByteStream

pub fn new<T>( value: impl Stream<Item = Result<T, ServerFnError>> + Send + 'static, ) -> ByteStream
where T: Into<Bytes>,

Creates a new ByteStream from the given stream.