pub struct JsonStream<T, CustErr = NoCustomError>(/* private fields */);Expand description
A stream of typed data encoded as JSON.
A server function can return this type if its output encoding is StreamingJson.
Browser Support for Streaming Input
Browser fetch requests do not currently support full request duplexing, which means that that they do begin handling responses until the full request has been sent. This means that if you use a streaming input encoding, the input stream needs to end before the output will begin.
Streaming requests are only allowed over HTTP2 or HTTP3.
Implementations
Sourceimpl<T> JsonStream<T>
impl<T> JsonStream<T>
Sourcepub fn new(
value: impl Stream<Item = Result<T, ServerFnError>> + Send + 'static,
) -> JsonStream<T>
pub fn new( value: impl Stream<Item = Result<T, ServerFnError>> + Send + 'static, ) -> JsonStream<T>
Creates a new ByteStream from the given stream.
Sourceimpl<T, CustErr> JsonStream<T, CustErr>
impl<T, CustErr> JsonStream<T, CustErr>
Sourcepub fn into_inner(
self,
) -> impl Stream<Item = Result<T, ServerFnError<CustErr>>> + Send
pub fn into_inner( self, ) -> impl Stream<Item = Result<T, ServerFnError<CustErr>>> + Send
Consumes the wrapper, returning a stream of text.