pub struct TextStream<CustErr = NoCustomError>(/* private fields */);Expand description
A stream of text.
A server function can return this type if its output encoding is StreamingText.
Browser Support for Streaming Input
Browser fetch requests do not currently support full request duplexing, which means that that they do begin handling responses until the full request has been sent. This means that if you use a streaming input encoding, the input stream needs to end before the output will begin.
Streaming requests are only allowed over HTTP2 or HTTP3.
Implementations
Sourceimpl TextStream
impl TextStream
Sourcepub fn new(
value: impl Stream<Item = Result<String, ServerFnError>> + Send + 'static,
) -> TextStream
pub fn new( value: impl Stream<Item = Result<String, ServerFnError>> + Send + 'static, ) -> TextStream
Creates a new ByteStream from the given stream.
Sourceimpl<CustErr> TextStream<CustErr>
impl<CustErr> TextStream<CustErr>
Sourcepub fn into_inner(
self,
) -> impl Stream<Item = Result<String, ServerFnError<CustErr>>> + Send
pub fn into_inner( self, ) -> impl Stream<Item = Result<String, ServerFnError<CustErr>>> + Send
Consumes the wrapper, returning a stream of text.