pub struct Request(/* private fields */);Expand description
The Request sent to the server
Implementations
Sourceimpl Request
impl Request
Sourcepub fn get(url: &str) -> RequestBuilder
pub fn get(url: &str) -> RequestBuilder
Creates a new GET Request with url.
Sourcepub fn post(url: &str) -> RequestBuilder
pub fn post(url: &str) -> RequestBuilder
Creates a new POST Request with url.
Sourcepub fn put(url: &str) -> RequestBuilder
pub fn put(url: &str) -> RequestBuilder
Creates a new PUT Request with url.
Sourcepub fn delete(url: &str) -> RequestBuilder
pub fn delete(url: &str) -> RequestBuilder
Creates a new DELETE Request with url.
Sourcepub fn patch(url: &str) -> RequestBuilder
pub fn patch(url: &str) -> RequestBuilder
Creates a new PATCH Request with url.
Sourcepub fn body_used(&self) -> bool
pub fn body_used(&self) -> bool
Has the request body been consumed?
If true, then any future attempts to consume the body will error.
Sourcepub fn body(&self) -> Option<ReadableStream>
pub fn body(&self) -> Option<ReadableStream>
Gets the body.
Sourcepub async fn form_data(&self) -> Result<FormData, Error>
pub async fn form_data(&self) -> Result<FormData, Error>
Reads the request to completion, returning it as FormData.
Sourcepub async fn json<T>(&self) -> Result<T, Error>where
T: DeserializeOwned,
pub async fn json<T>(&self) -> Result<T, Error>where
T: DeserializeOwned,
Reads the request to completion, parsing it as JSON.
Sourcepub async fn binary(&self) -> Result<Vec<u8>, Error>
pub async fn binary(&self) -> Result<Vec<u8>, Error>
Gets the binary request
This works by obtaining the response as an ArrayBuffer, creating a Uint8Array from it
and then converting it to Vec<u8>
Sourcepub fn mode(&self) -> RequestMode
pub fn mode(&self) -> RequestMode
Return the read only mode for the request