pub struct ServerFnTraitObj<Req, Res> { /* private fields */ }Expand description
A trait object that allows multiple server functions that take the same request type and return the same response type to be gathered into a single collection.
Implementations
Sourceimpl<Req, Res> ServerFnTraitObj<Req, Res>
impl<Req, Res> ServerFnTraitObj<Req, Res>
Sourcepub const fn new(
path: &'static str,
method: Method,
handler: fn(Req) -> Pin<Box<dyn Future<Output = Res> + Send>>,
middleware: fn() -> Vec<Arc<dyn Layer<Req, Res>>>,
) -> ServerFnTraitObj<Req, Res>
pub const fn new( path: &'static str, method: Method, handler: fn(Req) -> Pin<Box<dyn Future<Output = Res> + Send>>, middleware: fn() -> Vec<Arc<dyn Layer<Req, Res>>>, ) -> ServerFnTraitObj<Req, Res>
Converts the relevant parts of a server function into a trait object.
Sourcepub fn handler(&self, req: Req) -> impl Future<Output = Res> + Send
pub fn handler(&self, req: Req) -> impl Future<Output = Res> + Send
The handler for this server function.
Sourcepub fn middleware(&self) -> Vec<Arc<dyn Layer<Req, Res>>>
pub fn middleware(&self) -> Vec<Arc<dyn Layer<Req, Res>>>
The set of middleware that should be applied to this function.