pub struct ActionAbortHandle(/* private fields */);Expand description
A handle that allows aborting an in-flight action. It is returned from Action::dispatch or
ArcAction::dispatch.
Implementations
Sourceimpl ActionAbortHandle
impl ActionAbortHandle
Sourcepub fn abort(self)
pub fn abort(self)
Aborts the action.
This will cause the dispatched task to complete, without updating the action’s value. The
dispatched action’s Future will no longer be polled. This does not guarantee that side
effects created by that Future no longer run: for example, if the action dispatches an
HTTP request, whether that request is actually canceled or not depends on whether the
request library actually cancels a request when its Future is dropped.