pub struct AnimationFrameRequestHandle(/* private fields */);Expand description
Handle that is generated by request_animation_frame_with_handle and can be used to cancel the animation frame request.
Implementations
Sourceimpl AnimationFrameRequestHandle
impl AnimationFrameRequestHandle
Sourcepub fn cancel(&self)
pub fn cancel(&self)
Cancels the animation frame request to which this refers.
See cancelAnimationFrame()