AnyView

Struct AnyView 

pub struct AnyView { /* private fields */ }
A type-erased view. This can be used if control flow requires that multiple different types of view must be received, and it is either impossible or too cumbersome to use the EitherOf___ enums.

It can also be used to create recursive components, which otherwise cannot return themselves due to the static typing of the view tree.

Generally speaking, using AnyView restricts the amount of information available to the compiler and should be limited to situations in which it is necessary to preserve the maximum amount of type information possible.