Callback

Struct Callback 

pub struct Callback<In, Out = ()>(/* private fields */)
where
    In: 'static,
    Out: 'static;
Callbacks define a standard way to store functions and closures.

Example

#[component]
fn MyComponent(
    #[prop(into)] render_number: Callback<(i32,), String>,
) -> impl IntoView {
    view! {
        <div>
            {render_number.run((42,))}
        </div>
    }
}

fn test() -> impl IntoView {
    view! {
        <MyComponent render_number=move |x: i32| x.to_string()/>
    }
}

Implementations

Source

impl<In, Out> Callback<In, Out>
where In: 'static, Out: 'static,

pub fn new<F>(fun: F) -> Callback<In, Out>
where F: Fn(In) -> Out + Send + Sync + 'static,

Creates a new callback from the given function.

pub fn matches(&self, other: &Callback<In, Out>) -> bool

Returns true if both callbacks wrap the same underlying function pointer.