MaybeProp

Struct MaybeProp 

pub struct MaybeProp<T, S = SyncStorage>(/* private fields */)
where
    T: 'static,
    S: Storage<Option<T>> + Storage<SignalTypes<Option<T>, S>>;
A wrapping type for an optional component prop.

This can either be a signal or a non-reactive value, and may or may not have a value. In other words, this is an Option<Signal<Option<T>>>, but automatically flattens its getters.

This creates an extremely flexible type for component libraries, etc.

Examples

let (count, set_count) = signal(Some(2));
let double = |n| n * 2;
let double_count = MaybeProp::derive(move || count.get().map(double));
let memoized_double_count = Memo::new(move |_| count.get().map(double));
let static_value = 5;

// this function takes either a reactive or non-reactive value
fn above_3(arg: &MaybeProp<i32>) -> bool {
    // ✅ calling the signal clones and returns the value
    //    it is a shorthand for arg.get()q
    arg.get().map(|arg| arg > 3).unwrap_or(false)
}

assert_eq!(above_3(&None::<i32>.into()), false);
assert_eq!(above_3(&static_value.into()), true);
assert_eq!(above_3(&count.into()), false);
assert_eq!(above_3(&double_count), true);
assert_eq!(above_3(&memoized_double_count.into()), true);

Implementations

Source

impl<T> MaybeProp<T>
where T: Send + Sync,

pub fn derive( derived_signal: impl Fn() -> Option<T> + Send + Sync + 'static, ) -> MaybeProp<T>

Wraps a derived signal, i.e., any computation that accesses one or more reactive signals.

Source

impl<T> MaybeProp<T, LocalStorage>

pub fn derive_local( derived_signal: impl Fn() -> Option<T> + 'static, ) -> MaybeProp<T, LocalStorage>

Wraps a derived signal, i.e., any computation that accesses one or more reactive signals.