OnceResource

Struct OnceResource 

pub struct OnceResource<T, Ser = JsonSerdeCodec> { /* private fields */ }
A resource that only loads once.

Resources allow asynchronously loading data and serializing it from the server to the client, so that it loads on the server, and is then deserialized on the client. This improves performance by beginning data loading on the server when the request is made, rather than beginning it on the client after WASM has been loaded.

You can access the value of the resource either synchronously using .get() or asynchronously using .await.

Implementations

Source

impl<T, Ser> OnceResource<T, Ser>
where T: Send + Sync + 'static, Ser: Encoder<T> + Decoder<T>, <Ser as Encoder<T>>::Error: Debug, <Ser as Decoder<T>>::Error: Debug, <<Ser as Decoder<T>>::Encoded as FromEncodedStr>::DecodingError: Debug, <Ser as Encoder<T>>::Encoded: IntoEncodedString, <Ser as Decoder<T>>::Encoded: FromEncodedStr,

pub fn new_with_options( fut: impl Future<Output = T> + Send + 'static, blocking: bool, ) -> OnceResource<T, Ser>

Creates a new resource with the encoding Ser. If blocking is true, this is a blocking resource.

Blocking resources prevent any of the HTTP response from being sent until they have loaded. This is useful if you need their data to set HTML document metadata or information that needs to appear in HTTP headers.

pub fn map<U>(&self, f: impl FnOnce(&T) -> U) -> Option<U>

Synchronously, reactively reads the current value of the resource and applies the function f to its value if it is Some(_).

Source

impl<T, E, Ser> OnceResource<Result<T, E>, Ser>
where Ser: Encoder<Result<T, E>> + Decoder<Result<T, E>>, <Ser as Encoder<Result<T, E>>>::Error: Debug, <Ser as Decoder<Result<T, E>>>::Error: Debug, <<Ser as Decoder<Result<T, E>>>::Encoded as FromEncodedStr>::DecodingError: Debug, <Ser as Encoder<Result<T, E>>>::Encoded: IntoEncodedString, <Ser as Decoder<Result<T, E>>>::Encoded: FromEncodedStr, T: Send + Sync + 'static, E: Send + Sync + Clone + 'static,

pub fn and_then<U>(&self, f: impl FnOnce(&T) -> U) -> Option<Result<U, E>>

Applies the given function when a resource that returns Result<T, E> has resolved and loaded an Ok(_), rather than requiring nested .map() calls over the Option<Result<_, _>> returned by the resource.

This is useful when used with features like server functions, in conjunction with <ErrorBoundary/> and <Suspense/>, when these other components are left to handle the None and Err(_) states.

Source

impl<T, Ser> OnceResource<T, Ser>
where T: Send + Sync + 'static, Ser: 'static,

pub fn ready(&self) -> AsyncDerivedReadyFuture

Returns a Future that is ready when this resource has next finished loading.

Source

impl<T> OnceResource<T>

pub fn new(fut: impl Future<Output = T> + Send + 'static) -> OnceResource<T>

Creates a resource using JsonSerdeCodec for encoding/decoding the value.

pub fn new_blocking( fut: impl Future<Output = T> + Send + 'static, ) -> OnceResource<T>

Creates a blocking resource using JsonSerdeCodec for encoding/decoding the value.

Blocking resources prevent any of the HTTP response from being sent until they have loaded. This is useful if you need their data to set HTML document metadata or information that needs to appear in HTTP headers.

Source

impl<T> OnceResource<T, FromToStringCodec>

pub fn new_str( fut: impl Future<Output = T> + Send + 'static, ) -> OnceResource<T, FromToStringCodec>

Creates a resource using FromToStringCodec for encoding/decoding the value.

pub fn new_str_blocking( fut: impl Future<Output = T> + Send + 'static, ) -> OnceResource<T, FromToStringCodec>

Creates a blocking resource using FromToStringCodec for encoding/decoding the value.

Blocking resources prevent any of the HTTP response from being sent until they have loaded. This is useful if you need their data to set HTML document metadata or information that needs to appear in HTTP headers.