Selector

Struct Selector 

pub struct Selector<T>
where T: PartialEq + Eq + Clone + Hash + 'static,
{ /* private fields */ }
A conditional signal that only notifies subscribers when a change in the source signal’s value changes whether the given function is true.

You probably don’t need this, but it can be a very useful optimization in certain situations (e.g., “set the class selected if selected() == this_row_index) because it reduces them from O(n) to O(1).

let a = RwSignal::new(0);
let is_selected = Selector::new(move || a.get());
let total_notifications = StoredValue::new(0);
Effect::new_isomorphic({
    let is_selected = is_selected.clone();
    move |_| {
        if is_selected.selected(5) {
            total_notifications.update_value(|n| *n += 1);
        }
    }
});

assert_eq!(is_selected.selected(5), false);
assert_eq!(total_notifications.get_value(), 0);
a.set(5);

assert_eq!(is_selected.selected(5), true);
assert_eq!(total_notifications.get_value(), 1);
a.set(5);

assert_eq!(is_selected.selected(5), true);
assert_eq!(total_notifications.get_value(), 1);
a.set(4);

assert_eq!(is_selected.selected(5), false);

Implementations

Source

impl<T> Selector<T>
where T: PartialEq + Send + Sync + Eq + Clone + Hash + 'static,

pub fn new( source: impl Fn() -> T + Send + Sync + Clone + 'static, ) -> Selector<T>

Creates a new selector that compares values using PartialEq.

pub fn new_with_fn( source: impl Fn() -> T + Clone + Send + Sync + 'static, f: impl Fn(&T, &T) -> bool + Send + Sync + Clone + 'static, ) -> Selector<T>

Creates a new selector that compares values by returning true from a comparator function if the values are the same.

pub fn selected(&self, key: T) -> bool

Reactively checks whether the given key is selected.

pub fn remove(&self, key: &T)

Removes the listener for the given key.

pub fn clear(&self)

Clears the listeners for all keys.