pub struct ServerActionError { /* private fields */ }Expand description
An error that can be caused by a server action.
This is used for propagating errors from the server to the client when JS/WASM are not supported.
Implementations