pub struct ServerMultiAction<S>{ /* private fields */ }Expand description
A MultiAction that can be used to call a server function.
Implementations
Sourceimpl<S> ServerMultiAction<S>
impl<S> ServerMultiAction<S>
Sourcepub fn new() -> ServerMultiAction<S>
pub fn new() -> ServerMultiAction<S>
Creates a new MultiAction which, when dispatched, will call the server function S.
Methods from Deref<Target = MultiAction<S, Result<<S as ServerFn>::Output, ServerFnError<<S as ServerFn>::Error>>>>
Sourcepub fn dispatch(&self, input: I)
pub fn dispatch(&self, input: I)
Calls the async function with a reference to the input type as its argument.
This can be called any number of times: each submission will be dispatched, running
concurrently, and its status can be checked via the
submissions() signal.
async fn send_new_todo_to_api(task: String) -> usize {
// do something...
// return a task id
42
}
let add_todo = MultiAction::new(|task: &String| {
// `task` is given as `&String` because its value is available in `input`
send_new_todo_to_api(task.clone())
});
let submissions = add_todo.submissions();
let pending_submissions = move || {
submissions.with(|subs| subs.iter().filter(|sub| sub.pending().get()).count())
};
add_todo.dispatch("Buy milk".to_string());
assert_eq!(submissions.with(Vec::len), 1);
assert_eq!(pending_submissions(), 1);
add_todo.dispatch("???".to_string());
add_todo.dispatch("Profit!!!".to_string());
assert_eq!(submissions.with(Vec::len), 3);
assert_eq!(pending_submissions(), 3);
// when submissions resolve, they are not removed from the set
// however, their `pending` signal is now `false`, and this can be used to filter them
assert_eq!(submissions.with(Vec::len), 3);
assert_eq!(pending_submissions(), 0);Sourcepub fn dispatch_sync(&self, value: O)
pub fn dispatch_sync(&self, value: O)
Synchronously adds a submission with the given value.
This takes the output value, rather than the input, because it is adding a result, not an input.
This can be useful for use cases like handling errors, where the error can already be known on the client side.
async fn send_new_todo_to_api(task: String) -> usize {
// do something...
// return a task id
42
}
let add_todo = MultiAction::new(|task: &String| {
// `task` is given as `&String` because its value is available in `input`
send_new_todo_to_api(task.clone())
});
let submissions = add_todo.submissions();
let pending_submissions = move || {
submissions.with(|subs| subs.iter().filter(|sub| sub.pending().get()).count())
};
add_todo.dispatch("Buy milk".to_string());
assert_eq!(submissions.with(Vec::len), 1);
assert_eq!(pending_submissions(), 1);
add_todo.dispatch_sync(42);
assert_eq!(submissions.with(Vec::len), 2);
assert_eq!(pending_submissions(), 1);Sourcepub fn submissions(&self) -> ReadSignal<Vec<ArcSubmission<I, O>>>
pub fn submissions(&self) -> ReadSignal<Vec<ArcSubmission<I, O>>>
The set of all submissions to this multi-action.
async fn send_new_todo_to_api(task: String) -> usize {
// do something...
// return a task id
42
}
let add_todo = MultiAction::new(|task: &String| {
// `task` is given as `&String` because its value is available in `input`
send_new_todo_to_api(task.clone())
});
let submissions = add_todo.submissions();
add_todo.dispatch("Buy milk".to_string());
add_todo.dispatch("???".to_string());
add_todo.dispatch("Profit!!!".to_string());
assert_eq!(submissions.with(Vec::len), 3);Sourcepub fn version(&self) -> RwSignal<usize>
pub fn version(&self) -> RwSignal<usize>
How many times an action has successfully resolved.
async fn send_new_todo_to_api(task: String) -> usize {
// do something...
// return a task id
42
}
let add_todo = MultiAction::new(|task: &String| {
// `task` is given as `&String` because its value is available in `input`
send_new_todo_to_api(task.clone())
});
let version = add_todo.version();
add_todo.dispatch("Buy milk".to_string());
add_todo.dispatch("???".to_string());
add_todo.dispatch("Profit!!!".to_string());
assert_eq!(version.get(), 0);
// when they've all resolved
assert_eq!(version.get(), 3);Trait Implementations
Sourceimpl<S> Clone for ServerMultiAction<S>
impl<S> Clone for ServerMultiAction<S>
Sourcefn clone(&self) -> ServerMultiAction<S>
fn clone(&self) -> ServerMultiAction<S>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<S> Copy for ServerMultiAction<S>
Sourceimpl<S> Default for ServerMultiAction<S>
impl<S> Default for ServerMultiAction<S>
Sourcefn default() -> ServerMultiAction<S>
fn default() -> ServerMultiAction<S>
Returns the “default value” for a type. Read more
Sourceimpl<S> DefinedAt for ServerMultiAction<S>
impl<S> DefinedAt for ServerMultiAction<S>
Sourcefn defined_at(&self) -> Option<&'static Location<'static>>
fn defined_at(&self) -> Option<&'static Location<'static>>
Returns the location at which the signal was defined. This is usually simply
None in
release mode.Sourceimpl<S> Deref for ServerMultiAction<S>
impl<S> Deref for ServerMultiAction<S>
Sourceimpl<S> From<ServerMultiAction<S>> for MultiAction<S, Result<<S as ServerFn>::Output, ServerFnError<<S as ServerFn>::Error>>>
impl<S> From<ServerMultiAction<S>> for MultiAction<S, Result<<S as ServerFn>::Output, ServerFnError<<S as ServerFn>::Error>>>
Sourcefn from(
value: ServerMultiAction<S>,
) -> MultiAction<S, Result<<S as ServerFn>::Output, ServerFnError<<S as ServerFn>::Error>>>
fn from( value: ServerMultiAction<S>, ) -> MultiAction<S, Result<<S as ServerFn>::Output, ServerFnError<<S as ServerFn>::Error>>>
Converts to this type from the input type.