StoredValue

Struct StoredValue 

pub struct StoredValue<T, S = SyncStorage> { /* private fields */ }
A non-reactive, Copy handle for any value.

This allows you to create a stable reference for any value by storing it within the reactive system. Like the signal types (e.g., ReadSignal and RwSignal), it is Copy and 'static. Unlike the signal types, it is not reactive; accessing it does not cause effects to subscribe, and updating it does not notify anything else.

Implementations

Source

impl<T, S> StoredValue<T, S>
where T: 'static, S: Storage<ArcStoredValue<T>>,

pub fn new_with_storage(value: T) -> StoredValue<T, S>

Stores the given value in the arena allocator.

Source

impl<T> StoredValue<T>
where T: Send + Sync + 'static,

pub fn new(value: T) -> StoredValue<T>

Stores the given value in the arena allocator.

Source

impl<T> StoredValue<T, LocalStorage>
where T: 'static,

pub fn new_local(value: T) -> StoredValue<T, LocalStorage>

Stores the given value in the arena allocator.