pub struct Trigger { /* private fields */ }Expand description
A trigger is a data-less signal with the sole purpose of notifying other reactive code of a change.
This can be useful for when using external data not stored in signals, for example.
This is an arena-allocated Trigger, which is Copy and is disposed when its reactive
Owner cleans up. For a reference-counted trigger that lives
as long as a reference to it is alive, see ArcTrigger.
Implementations