Unsuspend

Struct Unsuspend 

pub struct Unsuspend<T>(/* private fields */);
A wrapper that prevents Suspense from waiting for any resource reads that happen inside Unsuspend.

Implementations

Source

impl<T> Unsuspend<T>

pub fn new(fun: impl FnOnce() -> T + Send + 'static) -> Unsuspend<T>

Wraps the given function, such that it is not called until all resources are ready.