pub struct UnsyncCallback<In, Out = ()>(/* private fields */)
where
In: 'static,
Out: 'static;Expand description
A callback type that is not required to be Send + Sync.
Implementations
Sourceimpl<In, Out> UnsyncCallback<In, Out>
impl<In, Out> UnsyncCallback<In, Out>
Sourcepub fn new<F>(f: F) -> UnsyncCallback<In, Out>where
F: Fn(In) -> Out + 'static,
pub fn new<F>(f: F) -> UnsyncCallback<In, Out>where
F: Fn(In) -> Out + 'static,
Creates a new callback from the given function.
Sourcepub fn matches(&self, other: &UnsyncCallback<In, Out>) -> bool
pub fn matches(&self, other: &UnsyncCallback<In, Out>) -> bool
Returns true if both callbacks wrap the same underlying function pointer.