pub struct ViewFnOnce(/* private fields */);Expand description
New-type wrapper for a function, which will only be called once and returns a view with From and
Default traits implemented to enable optional props in for example <Show> and <Suspense>.
Implementations