pub trait DirectiveAttribute<T, P, D>where
D: IntoDirective<T, P>,{
type Output;
// Required method
fn directive(self, handler: D, param: P) -> Self::Output;
}Expand description
Adds a directive to the element, which runs some custom logic in the browser when the element is created or hydrated.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".