pub struct EditorShellProps {
pub toolbar: ViewFn,
pub left: ViewFn,
pub right: ViewFn,
pub bottom: ViewFn,
pub status: ViewFn,
pub left_open: Option<RwSignal<bool>>,
pub right_open: Option<RwSignal<bool>>,
pub bottom_open: Option<RwSignal<bool>>,
pub left_size: Option<RwSignal<f64>>,
pub right_size: Option<RwSignal<f64>>,
pub bottom_size: Option<RwSignal<f64>>,
pub children: Children,
}Expand description
Props for the EditorShell component.
A code-editor layout with a top toolbar, collapsible and resizable left,
right, and bottom slots around the central children, and a status footer.
Each *_open signal toggles a slot’s visibility; providing a matching
*_size signal makes that slot resizable (and drives its pixel size) via an
inserted ResizeHandle.
Required Props
- children:
Children
Optional Props
- toolbar:
impl Into<ViewFn> - left:
impl Into<ViewFn> - right:
impl Into<ViewFn> - bottom:
impl Into<ViewFn> - status:
impl Into<ViewFn> - left_open:
RwSignal<bool> - right_open:
RwSignal<bool> - bottom_open:
RwSignal<bool> - left_size:
RwSignal<f64> - right_size:
RwSignal<f64> - bottom_size:
RwSignal<f64>
Fields
toolbar: ViewFnleft: ViewFnright: ViewFnbottom: ViewFnstatus: ViewFnleft_open: Option<RwSignal<bool>>right_open: Option<RwSignal<bool>>bottom_open: Option<RwSignal<bool>>left_size: Option<RwSignal<f64>>right_size: Option<RwSignal<f64>>bottom_size: Option<RwSignal<f64>>children: ChildrenImplementations
Sourceimpl EditorShellProps
impl EditorShellProps
Sourcepub fn builder() -> EditorShellPropsBuilder<((), (), (), (), (), (), (), (), (), (), (), ())>
pub fn builder() -> EditorShellPropsBuilder<((), (), (), (), (), (), (), (), (), (), (), ())>
Create a builder for building EditorShellProps.
On the builder, call .toolbar(...)(optional), .left(...)(optional), .right(...)(optional), .bottom(...)(optional), .status(...)(optional), .left_open(...)(optional), .right_open(...)(optional), .bottom_open(...)(optional), .left_size(...)(optional), .right_size(...)(optional), .bottom_size(...)(optional), .children(...) to set the values of the fields.
Finally, call .build() to create the instance of EditorShellProps.