pub struct InspectorSectionProps {
pub title: String,
pub default_open: bool,
pub actions: ViewFn,
pub children: ChildrenFn,
}Expand description
Props for the InspectorSection component.
A collapsible inspector section with a title header, optional actions
rendered on the header row, and a body of children. default_open
controls the initial expanded state.
Required Props
- title:
impl Into<String> - children:
ChildrenFn
Optional Props
- default_open:
bool - actions:
impl Into<ViewFn>
Fields
title: Stringdefault_open: boolactions: ViewFnchildren: ChildrenFnImplementations
Sourceimpl InspectorSectionProps
impl InspectorSectionProps
Sourcepub fn builder() -> InspectorSectionPropsBuilder<((), (), (), ())>
pub fn builder() -> InspectorSectionPropsBuilder<((), (), (), ())>
Create a builder for building InspectorSectionProps.
On the builder, call .title(...), .default_open(...)(optional), .actions(...)(optional), .children(...) to set the values of the fields.
Finally, call .build() to create the instance of InspectorSectionProps.