pub fn Disclosure(props: DisclosureProps) -> impl IntoViewExpand description
A collapsible section with a clickable title header that shows or hides its
children. Open state is controlled by the optional open signal, otherwise it starts
from default_open.
Required Props
- title:
impl Into<String> - children:
ChildrenFn
Optional Props
- open:
RwSignal<bool> - default_open:
bool