pub fn EditorShell(props: EditorShellProps) -> impl IntoViewExpand description
A code-editor layout with a top toolbar, collapsible and resizable left,
right, and bottom slots around the central children, and a status footer.
Each *_open signal toggles a slot’s visibility; providing a matching
*_size signal makes that slot resizable (and drives its pixel size) via an
inserted ResizeHandle.
Required Props
- children:
Children
Optional Props
- toolbar:
impl Into<ViewFn> - left:
impl Into<ViewFn> - right:
impl Into<ViewFn> - bottom:
impl Into<ViewFn> - status:
impl Into<ViewFn> - left_open:
RwSignal<bool> - right_open:
RwSignal<bool> - bottom_open:
RwSignal<bool> - left_size:
RwSignal<f64> - right_size:
RwSignal<f64> - bottom_size:
RwSignal<f64>