pub fn TextField(props: TextFieldProps) -> impl IntoViewExpand description
A single-line text field with optional help and error notes. Commits on change, or
debounces input by debounce milliseconds when set, emitting the text through
on_commit.
Required Props
- label:
impl Into<String> - value:
Signal<String> - on_commit:
Callback<String>
Optional Props
- placeholder:
impl Into<String> - help:
impl Into<String> - error:
impl Into<String> - disabled:
impl Into<Signal<bool>> - debounce:
u32