pub struct ByteStream<CustErr = NoCustomError>(/* private fields */);Expand description
A stream of bytes.
A server function can return this type if its output encoding is Streaming.
Browser Support for Streaming Input
Browser fetch requests do not currently support full request duplexing, which means that that they do begin handling responses until the full request has been sent. This means that if you use a streaming input encoding, the input stream needs to end before the output will begin.
Streaming requests are only allowed over HTTP2 or HTTP3.
Implementations
Sourceimpl<CustErr> ByteStream<CustErr>
impl<CustErr> ByteStream<CustErr>
Sourcepub fn into_inner(
self,
) -> impl Stream<Item = Result<Bytes, ServerFnError<CustErr>>> + Send
pub fn into_inner( self, ) -> impl Stream<Item = Result<Bytes, ServerFnError<CustErr>>> + Send
Consumes the wrapper, returning a stream of bytes.
Sourceimpl ByteStream
impl ByteStream
Sourcepub fn new<T>(
value: impl Stream<Item = Result<T, ServerFnError>> + Send + 'static,
) -> ByteStream
pub fn new<T>( value: impl Stream<Item = Result<T, ServerFnError>> + Send + 'static, ) -> ByteStream
Creates a new ByteStream from the given stream.