StreamingText

Struct StreamingText 

pub struct StreamingText;
An encoding that represents a stream of text.

A server function that uses this as its output encoding should return TextStream.

Browser Support for Streaming Input

Browser fetch requests do not currently support full request duplexing, which means that that they do begin handling responses until the full request has been sent. This means that if you use a streaming input encoding, the input stream needs to end before the output will begin.

Streaming requests are only allowed over HTTP2 or HTTP3.