pub struct ArcLocalResource<T> { /* private fields */ }Expand description
A reference-counted resource that only loads its data locally on the client.
Implementations
Sourceimpl<T> ArcLocalResource<T>
impl<T> ArcLocalResource<T>
Sourcepub fn new<Fut>(fetcher: impl Fn() -> Fut + 'static) -> ArcLocalResource<T>where
T: 'static,
Fut: Future<Output = T> + 'static,
pub fn new<Fut>(fetcher: impl Fn() -> Fut + 'static) -> ArcLocalResource<T>where
T: 'static,
Fut: Future<Output = T> + 'static,
Creates the resource.
This will only begin loading data if you are on the client (i.e., if you do not have the
ssr feature activated).
Sourcepub fn map<U>(&self, f: impl FnOnce(&SendWrapper<T>) -> U) -> Option<U>where
T: 'static,
pub fn map<U>(&self, f: impl FnOnce(&SendWrapper<T>) -> U) -> Option<U>where
T: 'static,
Synchronously, reactively reads the current value of the resource and applies the function
f to its value if it is Some(_).
Sourceimpl<T, E> ArcLocalResource<Result<T, E>>where
T: 'static,
E: Clone + 'static,
impl<T, E> ArcLocalResource<Result<T, E>>where
T: 'static,
E: Clone + 'static,
Sourcepub fn and_then<U>(&self, f: impl FnOnce(&T) -> U) -> Option<Result<U, E>>
pub fn and_then<U>(&self, f: impl FnOnce(&T) -> U) -> Option<Result<U, E>>
Applies the given function when a resource that returns Result<T, E>
has resolved and loaded an Ok(_), rather than requiring nested .map()
calls over the Option<Result<_, _>> returned by the resource.
This is useful when used with features like server functions, in conjunction
with <ErrorBoundary/> and <Suspense/>, when these other components are
left to handle the None and Err(_) states.