pub struct Dom;Expand description
A Renderer that uses web-sys to manipulate DOM elements in the browser.
Implementations
Sourceimpl Dom
impl Dom
pub fn intern(text: &str) -> &str
pub fn create_element(tag: &str, namespace: Option<&str>) -> Element
pub fn create_text_node(text: &str) -> Text
pub fn create_placeholder() -> Comment
pub fn set_text(node: &Text, text: &str)
pub fn set_attribute(node: &Element, name: &str, value: &str)
pub fn remove_attribute(node: &Element, name: &str)
pub fn insert_node(parent: &Element, new_child: &Node, anchor: Option<&Node>)
pub fn remove_node(parent: &Element, child: &Node) -> Option<Node>
pub fn remove(node: &Node)
pub fn get_parent(node: &Node) -> Option<Node>
pub fn first_child(node: &Node) -> Option<Node>
pub fn next_sibling(node: &Node) -> Option<Node>
pub fn log_node(node: &Node)
pub fn clear_children(parent: &Element)
Sourcepub fn mount_before<M>(new_child: &mut M, before: &Node)where
M: Mountable,
pub fn mount_before<M>(new_child: &mut M, before: &Node)where
M: Mountable,
Mounts the new child before the marker as its sibling.
Panics
The default implementation panics if before does not have a parent crate::renderer::types::Element.
Sourcepub fn try_mount_before<M>(new_child: &mut M, before: &Node) -> boolwhere
M: Mountable,
pub fn try_mount_before<M>(new_child: &mut M, before: &Node) -> boolwhere
M: Mountable,
Tries to mount the new child before the marker as its sibling.
Returns false if the child did not have a valid parent.
pub fn set_property(el: &Element, key: &str, value: &JsValue)
pub fn add_event_listener( el: &Element, name: &str, cb: Box<dyn FnMut(JsValue)>, ) -> RemoveEventHandler<Element>
pub fn add_event_listener_use_capture( el: &Element, name: &str, cb: Box<dyn FnMut(JsValue)>, ) -> RemoveEventHandler<Element>
pub fn event_target<T>(ev: &JsValue) -> T
pub fn add_event_listener_delegated( el: &Element, name: Cow<'static, str>, delegation_key: Cow<'static, str>, cb: Box<dyn FnMut(JsValue)>, ) -> RemoveEventHandler<Element>
pub fn class_list(el: &Element) -> DomTokenList
pub fn add_class(list: &DomTokenList, name: &str)
pub fn remove_class(list: &DomTokenList, name: &str)
pub fn style(el: &Element) -> CssStyleDeclaration
pub fn set_css_property(style: &CssStyleDeclaration, name: &str, value: &str)
pub fn remove_css_property(style: &CssStyleDeclaration, name: &str)
pub fn set_inner_html(el: &Element, html: &str)
pub fn get_template<V>() -> HtmlTemplateElementwhere
V: ToTemplate + 'static,
pub fn clone_template(tpl: &HtmlTemplateElement) -> Element
pub fn create_element_from_html(html: &str) -> Element