pub struct OnceResource<T, Ser = JsonSerdeCodec> { /* private fields */ }Expand description
A resource that only loads once.
Resources allow asynchronously loading data and serializing it from the server to the client, so that it loads on the server, and is then deserialized on the client. This improves performance by beginning data loading on the server when the request is made, rather than beginning it on the client after WASM has been loaded.
You can access the value of the resource either synchronously using .get() or asynchronously
using .await.
Implementations
Sourceimpl<T, Ser> OnceResource<T, Ser>
impl<T, Ser> OnceResource<T, Ser>
Sourcepub fn new_with_options(
fut: impl Future<Output = T> + Send + 'static,
blocking: bool,
) -> OnceResource<T, Ser>
pub fn new_with_options( fut: impl Future<Output = T> + Send + 'static, blocking: bool, ) -> OnceResource<T, Ser>
Creates a new resource with the encoding Ser. If blocking is true, this is a blocking
resource.
Blocking resources prevent any of the HTTP response from being sent until they have loaded. This is useful if you need their data to set HTML document metadata or information that needs to appear in HTTP headers.
Sourceimpl<T, E, Ser> OnceResource<Result<T, E>, Ser>where
Ser: Encoder<Result<T, E>> + Decoder<Result<T, E>>,
<Ser as Encoder<Result<T, E>>>::Error: Debug,
<Ser as Decoder<Result<T, E>>>::Error: Debug,
<<Ser as Decoder<Result<T, E>>>::Encoded as FromEncodedStr>::DecodingError: Debug,
<Ser as Encoder<Result<T, E>>>::Encoded: IntoEncodedString,
<Ser as Decoder<Result<T, E>>>::Encoded: FromEncodedStr,
T: Send + Sync + 'static,
E: Send + Sync + Clone + 'static,
impl<T, E, Ser> OnceResource<Result<T, E>, Ser>where
Ser: Encoder<Result<T, E>> + Decoder<Result<T, E>>,
<Ser as Encoder<Result<T, E>>>::Error: Debug,
<Ser as Decoder<Result<T, E>>>::Error: Debug,
<<Ser as Decoder<Result<T, E>>>::Encoded as FromEncodedStr>::DecodingError: Debug,
<Ser as Encoder<Result<T, E>>>::Encoded: IntoEncodedString,
<Ser as Decoder<Result<T, E>>>::Encoded: FromEncodedStr,
T: Send + Sync + 'static,
E: Send + Sync + Clone + 'static,
Sourcepub fn and_then<U>(&self, f: impl FnOnce(&T) -> U) -> Option<Result<U, E>>
pub fn and_then<U>(&self, f: impl FnOnce(&T) -> U) -> Option<Result<U, E>>
Applies the given function when a resource that returns Result<T, E>
has resolved and loaded an Ok(_), rather than requiring nested .map()
calls over the Option<Result<_, _>> returned by the resource.
This is useful when used with features like server functions, in conjunction
with <ErrorBoundary/> and <Suspense/>, when these other components are
left to handle the None and Err(_) states.
Sourceimpl<T, Ser> OnceResource<T, Ser>
impl<T, Ser> OnceResource<T, Ser>
Sourcepub fn ready(&self) -> AsyncDerivedReadyFuture ⓘ
pub fn ready(&self) -> AsyncDerivedReadyFuture ⓘ
Returns a Future that is ready when this resource has next finished loading.
Sourceimpl<T> OnceResource<T>where
T: Send + Sync + 'static,
JsonSerdeCodec: Encoder<T> + Decoder<T>,
<JsonSerdeCodec as Encoder<T>>::Error: Debug,
<JsonSerdeCodec as Decoder<T>>::Error: Debug,
<<JsonSerdeCodec as Decoder<T>>::Encoded as FromEncodedStr>::DecodingError: Debug,
<JsonSerdeCodec as Encoder<T>>::Encoded: IntoEncodedString,
<JsonSerdeCodec as Decoder<T>>::Encoded: FromEncodedStr,
impl<T> OnceResource<T>where
T: Send + Sync + 'static,
JsonSerdeCodec: Encoder<T> + Decoder<T>,
<JsonSerdeCodec as Encoder<T>>::Error: Debug,
<JsonSerdeCodec as Decoder<T>>::Error: Debug,
<<JsonSerdeCodec as Decoder<T>>::Encoded as FromEncodedStr>::DecodingError: Debug,
<JsonSerdeCodec as Encoder<T>>::Encoded: IntoEncodedString,
<JsonSerdeCodec as Decoder<T>>::Encoded: FromEncodedStr,
Sourcepub fn new(fut: impl Future<Output = T> + Send + 'static) -> OnceResource<T>
pub fn new(fut: impl Future<Output = T> + Send + 'static) -> OnceResource<T>
Creates a resource using JsonSerdeCodec for encoding/decoding the value.
Sourcepub fn new_blocking(
fut: impl Future<Output = T> + Send + 'static,
) -> OnceResource<T>
pub fn new_blocking( fut: impl Future<Output = T> + Send + 'static, ) -> OnceResource<T>
Creates a blocking resource using JsonSerdeCodec for encoding/decoding the value.
Blocking resources prevent any of the HTTP response from being sent until they have loaded. This is useful if you need their data to set HTML document metadata or information that needs to appear in HTTP headers.
Sourceimpl<T> OnceResource<T, FromToStringCodec>where
T: Send + Sync + 'static,
FromToStringCodec: Encoder<T> + Decoder<T>,
<FromToStringCodec as Encoder<T>>::Error: Debug,
<FromToStringCodec as Decoder<T>>::Error: Debug,
<<FromToStringCodec as Decoder<T>>::Encoded as FromEncodedStr>::DecodingError: Debug,
<FromToStringCodec as Encoder<T>>::Encoded: IntoEncodedString,
<FromToStringCodec as Decoder<T>>::Encoded: FromEncodedStr,
impl<T> OnceResource<T, FromToStringCodec>where
T: Send + Sync + 'static,
FromToStringCodec: Encoder<T> + Decoder<T>,
<FromToStringCodec as Encoder<T>>::Error: Debug,
<FromToStringCodec as Decoder<T>>::Error: Debug,
<<FromToStringCodec as Decoder<T>>::Encoded as FromEncodedStr>::DecodingError: Debug,
<FromToStringCodec as Encoder<T>>::Encoded: IntoEncodedString,
<FromToStringCodec as Decoder<T>>::Encoded: FromEncodedStr,
Sourcepub fn new_str(
fut: impl Future<Output = T> + Send + 'static,
) -> OnceResource<T, FromToStringCodec>
pub fn new_str( fut: impl Future<Output = T> + Send + 'static, ) -> OnceResource<T, FromToStringCodec>
Creates a resource using FromToStringCodec for encoding/decoding the value.
Sourcepub fn new_str_blocking(
fut: impl Future<Output = T> + Send + 'static,
) -> OnceResource<T, FromToStringCodec>
pub fn new_str_blocking( fut: impl Future<Output = T> + Send + 'static, ) -> OnceResource<T, FromToStringCodec>
Creates a blocking resource using FromToStringCodec for encoding/decoding the value.
Blocking resources prevent any of the HTTP response from being sent until they have loaded. This is useful if you need their data to set HTML document metadata or information that needs to appear in HTTP headers.