SharedValue

Struct SharedValue 

pub struct SharedValue<T, Ser = JsonSerdeCodec> { /* private fields */ }
A smart pointer that allows you to share identical, synchronously-loaded data between the server and the client.

If this constructed on the server, it serializes its value into the shared context. If it is constructed on the client during hydration, it reads its value from the shared context. If it it constructed on the client at any other time, it simply runs on the client.

Implementations

Source

impl<T, Ser> SharedValue<T, Ser>

pub fn into_inner(self) -> T

Returns the inner value.

Source

impl<T> SharedValue<T>

pub fn new(initial: impl FnOnce() -> T) -> SharedValue<T>

Wraps the initial value.

If this is on the server, the function will be invoked and the value serialized. When it runs on the client, it will be deserialized without running the function again.

This uses the JsonSerdeCodec encoding.

Source

impl<T> SharedValue<T, FromToStringCodec>

pub fn new_str(initial: impl FnOnce() -> T) -> SharedValue<T, FromToStringCodec>

Wraps the initial value.

If this is on the server, the function will be invoked and the value serialized. When it runs on the client, it will be deserialized without running the function again.

This uses the FromToStringCodec encoding.

Source

impl<T, Ser> SharedValue<T, Ser>
where Ser: Encoder<T> + Decoder<T>, <Ser as Encoder<T>>::Error: Debug, <Ser as Decoder<T>>::Error: Debug, <Ser as Encoder<T>>::Encoded: IntoEncodedString, <Ser as Decoder<T>>::Encoded: FromEncodedStr, <<Ser as Decoder<T>>::Encoded as FromEncodedStr>::DecodingError: Debug,

pub fn new_with_encoding(initial: impl FnOnce() -> T) -> SharedValue<T, Ser>

Wraps the initial value.

If this is on the server, the function will be invoked and the value serialized. When it runs on the client, it will be deserialized without running the function again.

This uses Ser as an encoding.