pub struct StoredValue<T, S = SyncStorage> { /* private fields */ }Expand description
A non-reactive, Copy handle for any value.
This allows you to create a stable reference for any value by storing it within
the reactive system. Like the signal types (e.g., ReadSignal
and RwSignal), it is Copy and 'static. Unlike the signal
types, it is not reactive; accessing it does not cause effects to subscribe, and
updating it does not notify anything else.
Implementations
Sourceimpl<T, S> StoredValue<T, S>where
T: 'static,
S: Storage<ArcStoredValue<T>>,
impl<T, S> StoredValue<T, S>where
T: 'static,
S: Storage<ArcStoredValue<T>>,
Sourcepub fn new_with_storage(value: T) -> StoredValue<T, S>
pub fn new_with_storage(value: T) -> StoredValue<T, S>
Stores the given value in the arena allocator.
Sourceimpl<T> StoredValue<T>
impl<T> StoredValue<T>
Sourcepub fn new(value: T) -> StoredValue<T>
pub fn new(value: T) -> StoredValue<T>
Stores the given value in the arena allocator.
Sourceimpl<T> StoredValue<T, LocalStorage>where
T: 'static,
impl<T> StoredValue<T, LocalStorage>where
T: 'static,
Sourcepub fn new_local(value: T) -> StoredValue<T, LocalStorage>
pub fn new_local(value: T) -> StoredValue<T, LocalStorage>
Stores the given value in the arena allocator.