pub struct ViewTemplate<V> { /* private fields */ }Expand description
A view wrapper that uses a <template> node to optimize DOM node creation.
Rather than creating all of the DOM nodes each time it is built, this template will create a
single <template> node once, then use .cloneNode(true) to clone that entire tree, and
hydrate it to add event listeners and interactivity for this instance.
Implementations
Sourceimpl<V> ViewTemplate<V>where
V: Render + ToTemplate + 'static,
impl<V> ViewTemplate<V>where
V: Render + ToTemplate + 'static,
Sourcepub fn new(view: V) -> ViewTemplate<V>
pub fn new(view: V) -> ViewTemplate<V>
Creates a new view template.